==> ejc-salary-api-3.0.0-20241008.084406-13-sources.jar: com/ejianc/business/salary/vo/JspayableSourceVO.java <==
package com.ejianc.business.salary.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 应发工资明细来源
 * 
 * @author generator
 * 
 */
public class JspayableSourceVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long jspayableDetailId; // 所属明细id
    private Long detailEmployeeId; // 员工主键
    private String detailEmployeeName; // 员工名称
    private String detailEmployeeCode; // 员工编码
    private Date month; // 月份
    private String idCard; // 证件号码
    private Long orgId; // 单位id
    private String orgName; // 单位名称
    private String orgCode; // 单位编码
    private Long sourceId; // 应发上传id
    private Long sourceDetailId; // 应发上传明细id
    private Date period; // 期间 应发工资计算的 月份


    public Date getPeriod() {
        return period;
    }

    public void setPeriod(Date period) {
        this.period = period;
    }

    public Long getJspayableDetailId() {
        return jspayableDetailId;
    }

    public void setJspayableDetailId(Long jspayableDetailId) {
        this.jspayableDetailId = jspayableDetailId;
    }
    public Long getDetailEmployeeId() {
        return detailEmployeeId;
    }

    public void setDetailEmployeeId(Long detailEmployeeId) {
        this.detailEmployeeId = detailEmployeeId;
    }
    public String getDetailEmployeeName() {
        return detailEmployeeName;
    }

    public void setDetailEmployeeName(String detailEmployeeName) {
        this.detailEmployeeName = detailEmployeeName;
    }
    public String getDetailEmployeeCode() {
        return detailEmployeeCode;
    }

    public void setDetailEmployeeCode(String detailEmployeeCode) {
        this.detailEmployeeCode = detailEmployeeCode;
    }
    public Date getMonth() {
        return month;
    }

    public void setMonth(Date month) {
        this.month = month;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    
}

==> ejc-salary-api-3.0.0-20250820.033007-166-sources.jar: com/ejianc/business/salary/vo/JspayableSourceVO.java <==
package com.ejianc.business.salary.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 应发工资明细来源
 * 
 * @author generator
 * 
 */
public class JspayableSourceVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long jspayableDetailId; // 所属明细id
    private Long detailEmployeeId; // 员工主键
    private String detailEmployeeName; // 员工名称
    private String detailEmployeeCode; // 员工编码
    private Date month; // 月份
    private String idCard; // 证件号码
    private Long orgId; // 单位id
    private String orgName; // 单位名称
    private String orgCode; // 单位编码
    private Long sourceId; // 应发上传id
    private Long sourceDetailId; // 应发上传明细id
    private Date period; // 期间 应发工资计算的 月份
    private Long companyId; // 汇总单所属公司id
    private String companyName; // 汇总单所属公司

    public Long getCompanyId() {
        return companyId;
    }

    public void setCompanyId(Long companyId) {
        this.companyId = companyId;
    }

    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }


    public Date getPeriod() {
        return period;
    }

    public void setPeriod(Date period) {
        this.period = period;
    }

    public Long getJspayableDetailId() {
        return jspayableDetailId;
    }

    public void setJspayableDetailId(Long jspayableDetailId) {
        this.jspayableDetailId = jspayableDetailId;
    }
    public Long getDetailEmployeeId() {
        return detailEmployeeId;
    }

    public void setDetailEmployeeId(Long detailEmployeeId) {
        this.detailEmployeeId = detailEmployeeId;
    }
    public String getDetailEmployeeName() {
        return detailEmployeeName;
    }

    public void setDetailEmployeeName(String detailEmployeeName) {
        this.detailEmployeeName = detailEmployeeName;
    }
    public String getDetailEmployeeCode() {
        return detailEmployeeCode;
    }

    public void setDetailEmployeeCode(String detailEmployeeCode) {
        this.detailEmployeeCode = detailEmployeeCode;
    }
    public Date getMonth() {
        return month;
    }

    public void setMonth(Date month) {
        this.month = month;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    
}
